*===================================================================*
*		Contribution of flows to structural change: Ownership		*
*===================================================================*


use "..\data\data_user", clear


*	Data preparation
*------------------------------>

xtset id year
replace sectorv = -3 if indus==5

gen old_sector = sectorv
replace old_sector = l.old_sector if old_sector==.

gen l_abroad = abroadv
replace l_abroad = l.l_abroad if l_abroad==.


gen new_year= 2007-year

xtset id new_year
gen new_sector = sectorv
replace new_sector = l.new_sector if new_sector==.

gen f_abroad = abroadv
replace f_abroad = l.f_abroad if f_abroad==.

xtset id year

egen aux2 = max(year*(workv!=.)), by(id) 
gen last_job = year ==aux2

egen aux3 = max(new_year*(workv!=.)), by(id) 
gen first_job = new_year == aux3   


capture drop aux?


replace unemp_a = 1 if f.first_job==1 & unemp_a ==. 
replace old_sector = . if f.first_job==1



*** FLOW MEASURES
*----------------------------

* Flow public sector (2017)

gen un_pub = unemp_a==1 & f.unemp_a==0 & f.sectorv==1 & f.first_job==1 & year!=1989
gen re_pub = unemp_a==2 & f.unemp_a==0 & f.sectorv==1 & f.f_abroad!=1 & abroadv!=1
gen in_pub = unemp_a==3 & f.unemp_a==0 & f.sectorv==1 & f.f_abroad!=1 & abroadv!=1
gen sc_pub = unemp_a==4 & f.unemp_a==0 & f.sectorv==1 & f.f_abroad!=1 & abroadv!=1
gen ni_pub = unemp_a==5 & f.unemp_a==0 & f.sectorv==1 & f.f_abroad!=1 & abroadv!=1


gen pub_re = f.unemp_a==2 & unemp_a==0 & sectorv==1 & last_job==1 & abroad!=1
gen pub_in = f.unemp_a==3 & unemp_a==0 & sectorv==1 & last_job==1 & abroad!=1
gen pub_sc = f.unemp_a==4 & unemp_a==0 & sectorv==1 & last_job==1 & abroad!=1
gen pub_ni = f.unemp_a==5 & unemp_a==0 & sectorv==1 & last_job==1 & abroad!=1
gen pub_un = f.unemp_a==1 & unemp_a==0 & sectorv==1 & last_job==1 & abroad!=1

* Private sector (2017)
 
gen un_pri = unemp_a==1 & f.unemp_a==0 & f.first_job==1 & f.sectorv>1 & f.sectorv!=. & f.abroadv!=1
gen re_pri = unemp_a==2 & f.unemp_a==0 & f.first_job==1 & f.sectorv>1 & f.sectorv!=. & f.abroadv!=1
gen in_pri = unemp_a==3 & f.unemp_a==0 & f.first_job==1 & f.sectorv>1 & f.sectorv!=. & f.abroadv!=1 
gen sc_pri = unemp_a==4 & f.unemp_a==0 & f.first_job==1 & f.sectorv>1 & f.sectorv!=. & f.abroadv!=1
gen ni_pri = unemp_a==5 & f.unemp_a==0 & f.first_job==1 & f.sectorv>1 & f.sectorv!=. & f.abroadv!=1

gen pri_un = f.unemp_a==1 & unemp_a==0 & (sectorv>1  & sectorv!=1) & last_job==1 & abroadv!=1
gen pri_re = f.unemp_a==2 & unemp_a==0 & (sectorv>1  & sectorv!=1) & last_job==1 & abroadv!=1
gen pri_in = f.unemp_a==3 & unemp_a==0 & (sectorv>1  & sectorv!=1) & last_job==1 & abroadv!=1
gen pri_sc = f.unemp_a==4 & unemp_a==0 & (sectorv>1  & sectorv!=1) & last_job==1 & abroadv!=1
gen pri_ni = f.unemp_a==5 & unemp_a==0 & (sectorv>1  & sectorv!=1) & last_job==1 & abroadv!=1

* Between sectors

capture drop pri_pub*
gen pri_pub= unemp_a==0 & f.unemp_a==0 & f.sectorv==1 & (sectorv>1 & sectorv!=.) & f.f_abroad!=1 & abroadv!=1
replace pri_pub= 1 if unemp_a==0 & f.unemp_a!=0 & (sectorv>1 & sectorv!=.) & (f.new_sector==1 ) & f.f_abroad!=1 & abroadv!=1

capture drop pub_pri*
gen pub_pri = unemp_a==0 & f.unemp_a==0 & sectorv==1 & (f.sectorv>1 & f.sectorv!=.) & f.f_abroad!=1&  abroadv!=1
replace pub_pri = 1 if f.unemp_a!=0 & unemp_a ==0 & sectorv==1 & f.new_sector>1 & f.new_sector!=. & f.f_abroad!=1&  abroadv!=1


 
** Figures
*-------------->

* Figure 4

preserve
collapse (sum) un_pub-pub_pri (first) country ,by(c_code )

foreach var in pub pri{
gen net_un_`var' =	un_`var' -`var'_un
gen net_re_`var' =	re_`var' -`var'_re
gen net_in_`var' =    in_`var' -`var'_in
gen net_sc_`var' =  	sc_`var' -`var'_sc
gen net_ni_`var' = 	ni_`var' -`var'_ni
gen net_ne_`var' = net_un_`var' + net_in_`var' + net_ni_`var' 
}

gen net_pri_pub= pri_pub - pub_pri
gen net_pub_pri= pub_pri - pri_pub

* Upper panel
graph hbar 	(asis) net_sc_pub  net_re_pub  net_pri_pub  net_ne_pub , over(c_code, label(labsize(vsmall)) axis(outergap(1)) sort(region_id)) stack  ///
			legend(order( 2  "Retirement" 3 "Private" 4 "Non-employment" 1 " School" ) /// 
			size(vsmall) r(1) textwidth(60) region(lcolor(none))) scheme(s1mono)  ///
			name(bars_out_pub, replace) saving(bars_out_pub, replace)  ///
			ylabel(,labsize(vsmall)) ///
			bar(1, fcolor(black) fintensity(100) lcolor(black)) ///
			bar(2, fcolor(black) fintensity(25) lcolor(black)) ///
			bar(3, fcolor(black) fintensity(50) lcolor(black)) ///
			bar(4, fcolor(black) fintensity(0) lcolor(black)) 

 

* Lower panel
graph hbar 	(asis) net_sc_pri  net_re_pri  net_pub_pri  net_ne_pri , over(c_code, label(labsize(vsmall)) axis(outergap(1)) sort(region_id)) stack  ///
			legend(order( 2  "Retirement" 3 " SOE" 4 "Non-employment" 1 " School" ) /// 
			size(vsmall) r(1) textwidth(60) region(lcolor(none))) scheme(s1mono)  ///
			name(bars_out_pri, replace) saving(bars_out_pub, replace)  ///
			ylabel(,labsize(vsmall)) ///
			bar(1, fcolor(black) fintensity(100) lcolor(black)) ///
			bar(2, fcolor(black) fintensity(25) lcolor(black)) ///
			bar(3, fcolor(black) fintensity(50) lcolor(black)) ///
			bar(4, fcolor(black) fintensity(0) lcolor(black)) 
restore
 

* Figures C2-C3 (Appendix) 

 
preserve
recode year (1991/1995=0) (1996/2001 =1) (1989 1990 = .) (2002/2006 =.), gen(period)  
encode region , gen(region_id)
collapse (sum) un_pub-pub_pri (first) country ,by(c_code period)

foreach var in pub pri{
gen net_un_`var' =	un_`var' -`var'_un
gen net_re_`var' =	re_`var' -`var'_re
gen net_in_`var' =    in_`var' -`var'_in
gen net_sc_`var' =  	sc_`var' -`var'_sc
gen net_ni_`var' = 	ni_`var' -`var'_ni
gen net_ne_`var' = net_un_`var' + net_in_`var' + net_ni_`var' 
}

gen net_pri_pub= pri_pub - pub_pri
gen net_pub_pri= pub_pri - pri_pub

 
*Figure C2
graph hbar 	(asis) net_sc_pub  net_re_pub  net_pri_pub  net_ne_pub if period==0, ///
			over(c_code, label(labsize(vsmall)) axis(outergap(1)) sort(region_id)) stack  ///
			legend(order( 2  "Retirement" 3 "Private" 4 "Non-employment" 1 " School" ) /// 
			size(vsmall) r(1) textwidth(60) region(lcolor(none))) scheme(s1mono)  ///
			name(bars_out_pub_0, replace) saving(bars_out_pub, replace)  ///
			ylabel(,labsize(vsmall)) ///
			bar(1, fcolor(black) fintensity(100) lcolor(black)) ///
			bar(2, fcolor(black) fintensity(25) lcolor(black)) ///
			bar(3, fcolor(black) fintensity(50) lcolor(black)) ///
			bar(4, fcolor(black) fintensity(0) lcolor(black)) 

 
graph hbar 	(asis) net_sc_pub  net_re_pub  net_pri_pub  net_ne_pub if period==1, ///
			over(c_code, label(labsize(vsmall)) axis(outergap(1)) sort(region_id)) stack  ///
			legend(order( 2  "Retirement" 3 "Private" 4 "Non-employment" 1 " School" ) /// 
			size(vsmall) r(1) textwidth(60) region(lcolor(none))) scheme(s1mono)  ///
			name(bars_out_pub_1, replace) saving(bars_out_pub, replace)  ///
			ylabel(,labsize(vsmall)) ///
			bar(1, fcolor(black) fintensity(100) lcolor(black)) ///
			bar(2, fcolor(black) fintensity(25) lcolor(black)) ///
			bar(3, fcolor(black) fintensity(50) lcolor(black)) ///
			bar(4, fcolor(black) fintensity(0) lcolor(black)) 
 
* Figure C3
graph hbar 	(asis) net_sc_pri  net_re_pri  net_pub_pri  net_ne_pri if period==0, ///
			over(c_code, label(labsize(vsmall)) axis(outergap(1)) sort(region_id)) stack  ///
			legend(order( 2  "Retirement" 3 "SOE" 4 "Non-employment" 1 " School" ) /// 
			size(vsmall) r(1) textwidth(60) region(lcolor(none))) scheme(s1mono)  ///
			name(bars_out_pri_0, replace) saving(bars_out_pub, replace)  ///
			ylabel(,labsize(vsmall)) ///
			bar(1, fcolor(black) fintensity(100) lcolor(black)) ///
			bar(2, fcolor(black) fintensity(25) lcolor(black)) ///
			bar(3, fcolor(black) fintensity(50) lcolor(black)) ///
			bar(4, fcolor(black) fintensity(0) lcolor(black)) 
 

graph hbar 	(asis) net_sc_pri  net_re_pri  net_pub_pri  net_ne_pri if period==1, ///
			over(c_code, label(labsize(vsmall)) axis(outergap(1)) sort(region_id)) stack  ///
			legend(order( 2  "Retirement" 3 "SOE" 4 "Non-employment" 1 " School" ) /// 
			size(vsmall) r(1) textwidth(60) region(lcolor(none))) scheme(s1mono)  ///
			name(bars_out_pri_1, replace) saving(bars_out_pub, replace)  ///
			ylabel(,labsize(vsmall)) ///
			bar(1, fcolor(black) fintensity(100) lcolor(black)) ///
			bar(2, fcolor(black) fintensity(25) lcolor(black)) ///
			bar(3, fcolor(black) fintensity(50) lcolor(black)) ///
			bar(4, fcolor(black) fintensity(0) lcolor(black)) 
restore

