*===================================================================*
*		Contribution of flows to structural change: Industry		*
*===================================================================*
 

use "..\data\data_user", clear

replace industryv = . if workv==.

xtset id year

gen old_ind = industryv
gen new_ind = industryv
forvalues i = 1/26{
replace old_ind = l.old_ind if old_ind==.
replace new_ind = f.new_ind if new_ind==.
replace abroadv = f.abroadv if abroadv==.
}

gen aux1 = year if workv!=.
replace aux1 = 0 if workv ==.
egen aux2 = max(aux1), by(id) 
gen last_job = year ==aux2

replace aux1 = 9999 if workv ==.
egen aux3 = min(aux1), by(id) 
gen first_job = year == aux3   
capture drop aux?
 
replace unemp_a = 1 if f.first_job==1 & unemp_a ==. 
replace old_ind = . if f.first_job==1


*** FLOW MEASURES
*----------------------------

** Manufacture
gen un_man = l.unemp_a==1 & unemp_a==0 & industryv==2 & first_job==1 & year!=1989
gen re_man = l.unemp_a==2 & unemp_a==0 & industryv==2
gen in_man = l.unemp_a==3 & unemp_a==0 & industryv==2
gen sc_man = l.unemp_a==4 & unemp_a==0 & industryv==2
gen ni_man = l.unemp_a==5 & unemp_a==0 & industryv==2

gen serv_man= l.unemp_a==0 & unemp_a==0 & industryv==2 & (l.industryv==4 | l.industryv==5)
replace serv_man= 1 if l.unemp_a==1 & unemp_a==0 & industryv==2 & (l.old_ind==4 | l.old_ind==5)

 
gen man_re = unemp_a==2 & l.unemp_a==0 & l.industryv==2
gen man_in = unemp_a==3 & l.unemp_a==0 & l.industryv==2
gen man_sc = unemp_a==4 & l.unemp_a==0 & l.industryv==2
gen man_ni = unemp_a==5 & l.unemp_a==0 & l.industryv==2
gen man_un = unemp_a==1 & l.unemp_a==0 & l.industryv==2 & l.last_job==1  & f.abroad!=1

gen man_serv = unemp_a==0 & l.unemp_a==0 & l.industryv==2 & (industryv==4 |industryv==5)
replace man_serv = 1 if unemp_a==1 & l.unemp_a ==0 & l.industryv==3 &  (new_ind==4 |new_ind==5)& f.abroadv!=1
 
 
** Services 
gen un_serv = l.unemp_a==1 & unemp_a==0 & (industryv==4) & first_job==1
gen re_serv = l.unemp_a==2 & unemp_a==0 & (industryv==4)
gen in_serv = l.unemp_a==3 & unemp_a==0 & (industryv==4)
gen sc_serv = l.unemp_a==4 & unemp_a==0 & (industryv==4)
gen ni_serv = l.unemp_a==5 & unemp_a==0 & (industryv==4)

 

gen serv_un = unemp_a==1 & l.unemp_a==0 & (l.industryv==4 | l.industryv==4) & l.last_job==1
gen serv_re = unemp_a==2 & l.unemp_a==0 & (l.industryv==4 | l.industryv==4)
gen serv_in = unemp_a==3 & l.unemp_a==0 & (l.industryv==4 | l.industryv==4)
gen serv_sc = unemp_a==4 & l.unemp_a==0 & (l.industryv==4 | l.industryv==4)
gen serv_ni = unemp_a==5 & l.unemp_a==0 & (l.industryv==4 | l.industryv==4)

collapse (sum) un_man-serv_ni (first) country ,by(c_code year)
xtset country year, yearly



** Figure 5
*-----------------------

foreach pr in un re in sc ni{
gen net_`pr'_man  =	f.`pr'_man -f.man_`pr'
gen net_`pr'_serv =	f.`pr'_serv -f.serv_`pr'
}

gen net_serv_man= 	f.serv_man-f.man_serv
gen net_man_serv= 	f.man_serv-f.serv_man
 
 
* Upper panel 
preserve
collapse (sum) net_un_man  net_re_man  net_in_man  net_sc_man   ///
			net_ni_man  net_serv_man  net_un_serv  net_re_serv  ///
			net_in_serv  net_sc_serv  net_ni_serv net_man_serv  ///
			, by(c_code )
 
gen c7 =  end_un_man + end_in_man + end_ni_man
gen c8 =  net_un_serv + net_in_serv + net_ni_serv  
 
graph hbar 	(asis) end_sc_man end_re_man end_serv_man  c7  , ///
			over(c_code, label(labsize(vsmall)) axis(outergap(1)) sort(region_id)) stack  ///
			legend(order( 2  "Retirement" 3 " Services" 4 "Non-employment" 1 " School" ) /// 
			size(vsmall) r(1) textwidth(60) region(lcolor(none))) scheme(s1mono)  ///
			name(bars_out_man, replace)    ///
			ylabel(,labsize(vsmall)) ///
			bar(1, fcolor(black) fintensity(100) lcolor(black)) ///
			bar(2, fcolor(black) fintensity(25) lcolor(black)) ///
			bar(3, fcolor(black) fintensity(50) lcolor(black)) ///
			bar(4, fcolor(black) fintensity(0) lcolor(black)) 
 
* Lower panel 
graph hbar 	(asis) net_re_serv  net_sc_serv  net_man_serv c6 c7 , over(c_code, label(labsize(vsmall)) sort(region_id)  ) stack  ///
			legend(order( 1 " Retirement" 3 " Manufactures" 4 " Non-employment" 2 " School"  ) ///
			size(vsmall) r(1) textwidth(60) region(lcolor(none))) ylabel(,labsize(vsmall)) ///
			  name(bars_out_serv, replace)   scheme(s1mono) ///
			bar(1, fcolor(black) fintensity(25) lcolor(black)) ///
			bar(2, fcolor(black) fintensity(100) lcolor(black)) ///
			bar(3, fcolor(black) fintensity(50) lcolor(black)) ///
			bar(4, fcolor(black) fintensity(0) lcolor(black)) 
restore			 
			 



* Figure C4 - C5

preserve
recode year (1991/1995=0) (1996/2001 =1) (1989 1990 = .) (2002/2006 =.), gen(period)  
encode region , gen(region_id)
collapse (sum) net_un_man  net_re_man  net_in_man  net_sc_man   ///
			net_ni_man  net_serv_man  net_un_serv  net_re_serv  ///
			net_in_serv  net_sc_serv  net_ni_serv net_man_serv ///
			(first) country ,by(c_code  period)

foreach pr in un re in sc ni{
gen net_`pr'_man  =	f.`pr'_man -f.man_`pr'
gen net_`pr'_serv =	f.`pr'_serv -f.serv_`pr'
}

gen net_ne_man = net_un_man + net_in_man + net_ni_man 
gen net_ne_serv = net_un_serv + net_in_serv + net_ni_serv 

gen net_ser_man= ser_man - man_ser
gen net_man_ser= man_ser - ser_man

 
*Figure C4
graph hbar 	(asis) net_sc_man  net_re_man  net_ser_man  net_ne_man if period==0, ///
			over(c_code, label(labsize(vsmall)) axis(outergap(1)) sort(region_id)) stack  ///
			legend(order( 2  "Retirement" 3 "Services" 4 "Non-employment" 1 " School" ) /// 
			size(vsmall) r(1) textwidth(60) region(lcolor(none))) scheme(s1mono)  ///
			name(bars_out_man_0, replace) saving(bars_out_man, replace)  ///
			ylabel(,labsize(vsmall)) ///
			bar(1, fcolor(black) fintensity(100) lcolor(black)) ///
			bar(2, fcolor(black) fintensity(25) lcolor(black)) ///
			bar(3, fcolor(black) fintensity(50) lcolor(black)) ///
			bar(4, fcolor(black) fintensity(0) lcolor(black)) 


graph hbar 	(asis) net_sc_man  net_re_man  net_ser_man  net_ne_man if period==1, ///
			over(c_code, label(labsize(vsmall)) axis(outergap(1)) sort(region_id)) stack  ///
			legend(order( 2  "Retirement" 3 "Services" 4 "Non-employment" 1 " School" ) /// 
			size(vsmall) r(1) textwidth(60) region(lcolor(none))) scheme(s1mono)  ///
			name(bars_out_man_1, replace) saving(bars_out_man, replace)  ///
			ylabel(,labsize(vsmall)) ///
			bar(1, fcolor(black) fintensity(100) lcolor(black)) ///
			bar(2, fcolor(black) fintensity(25) lcolor(black)) ///
			bar(3, fcolor(black) fintensity(50) lcolor(black)) ///
			bar(4, fcolor(black) fintensity(0) lcolor(black)) 
 
*Figure C5
graph hbar 	(asis) net_sc_ser  net_re_ser  net_man_ser  net_ne_ser if period==0, ///
			over(c_code, label(labsize(vsmall)) axis(outergap(1)) sort(region_id)) stack  ///
			legend(order( 2  "Retirement" 3 "Manufacture" 4 "Non-employment" 1 " School" ) /// 
			size(vsmall) r(1) textwidth(60) region(lcolor(none))) scheme(s1mono)  ///
			name(bars_out_ser_0, replace) saving(bars_out_man, replace)  ///
			ylabel(,labsize(vsmall)) ///
			bar(1, fcolor(black) fintensity(100) lcolor(black)) ///
			bar(2, fcolor(black) fintensity(25) lcolor(black)) ///
			bar(3, fcolor(black) fintensity(50) lcolor(black)) ///
			bar(4, fcolor(black) fintensity(0) lcolor(black)) 

 
graph hbar 	(asis) net_sc_ser  net_re_ser  net_man_ser  net_ne_ser if period==1, ///
			over(c_code, label(labsize(vsmall)) axis(outergap(1)) sort(region_id)) stack  ///
			legend(order( 2  "Retirement" 3 "Manufacture" 4 "Non-employment" 1 " School" ) /// 
			size(vsmall) r(1) textwidth(60) region(lcolor(none))) scheme(s1mono)  ///
			name(bars_out_ser_1, replace) saving(bars_out_man, replace)  ///
			ylabel(,labsize(vsmall)) ///
			bar(1, fcolor(black) fintensity(100) lcolor(black)) ///
			bar(2, fcolor(black) fintensity(25) lcolor(black)) ///
			bar(3, fcolor(black) fintensity(50) lcolor(black)) ///
			bar(4, fcolor(black) fintensity(0) lcolor(black)) 
