*===================================================*
*		The structure of flows -- bar graphs		*
*===================================================*

use "..\data\data_user", clear

gen emp = unemp_a ==0
gen act = unemp_a<2

replace act = 0 if indus==1 | indus==5

capture gen ab_np2 = (ab0==1 | abch0==1) & firmtypev!=2
capture gen ab_p2 =  (ab0==1 | abch0==1)  & firmtypev==2

*    Figure 1
*--------------------------
preserve
collapse (sum) act ab0 ch0 none0 abch0  anti0  t_retire2_a f_school_a ab_np ab_p ab_np2 ab_p2 ///
		(first) c_code [iw=weight_1], by(country year)

xtset country year

foreach var in ab0 ch0 none0 abch0 anti0 t_retire2_a f_school_a ab_np ab_p ab_np2 ab_p2{
replace `var' = `var' / act
}

egen sum1  = rowtotal(ab0-f_school_a)
egen sumer  = total(sum1) , by(c_code)


* Figure 1 -- upper panel
graph bar (mean) ab0 ch0 abch0  none0 anti0 f_school_a t_retire2_a  , ///
		over(c_code, sort(sumer) descending gap(*.5) label(labsize(vsmall))) ///
		stack horizontal  label legend(size(vsmall) rows(2)) scheme(s1mono) name(gr1_col2, replace) ///
		legend(order(1 "OWNERSHIP" 2 "SECTORAL" 3 "OWN. & SECT"  4  "SAME" ///
		5 "OPPOSITE" 6 "ENTRY" 7 "EXIT") region(lcolor(white)))  ///
		yti("Fraction of active workers", size(small)) ylab(,nogrid) xsize(6) ///
		bar(1, fcolor(dknavy) lcolor(white) fintensity(100)) ///
		bar(2, fcolor(dknavy) lcolor(white) fintensity(60)) ///
		bar(3, fcolor(dknavy) lcolor(white) fintensity(40)) ///
		bar(4, fcolor(black) lcolor(white) fintensity(40)) ///
		bar(5, fcolor(black) lcolor(white) fintensity(10)) ///
		bar(6, fcolor(maroon) lcolor(white) fintensity(40)) ///
		bar(7, fcolor(maroon) lcolor(white) fintensity(90))		

graph export ..\graphs\bar_weighted_mean_flows.eps, replace			
		
* Figure 1 -- lower panel		
graph bar (mean) ab_p2 ab_np2 , ///
		over(c_code, sort(sumer) descending gap(*.5) label(labsize(vsmall))) ///
		stack horizontal  label legend(size(vsmall) cols(2) ) scheme(s1mono) ///
		yti("Fraction of active workers", size(small)) ylab(,nogrid) ///
		legend(order(1 "PRIVATIZATION" 2 "DE NOVO" 3 "" 4 "" ) region(lcolor(white))) ///
		 bar(1, fcolor(dknavy) lcolor(white) fintensity(95)) ///
		bar(2, fcolor(dknavy) lcolor(white) fintensity(70))		

graph export ..\graphs\bar_weighted_mean_abnp.eps, replace				
		
restore		
		

		
*    Figure C.1	
*--------------------------

recode year (1991/1995=1) (1996/2000=2) (2001/2005=3) ///
			(1989 1990 2006=0), gen(period)	
  
preserve

collapse (sum) ab0 ch0 abch0 none0 anti0 f_school_a t_retire2_a  act  ///
		(first) period [aw=weight_1]  , by(c_code year)

foreach var in ab0 ch0 abch0 none0 anti0 f_school_a t_retire2_a{
replace `var' = `var'/act
}

collapse (mean) ab0 ch0 abch0 none0 anti0 f_school_a t_retire2_a    , by(c_code period)

label var ab0 			"OWNERSHIP"
label var ch0 			"SECTORAL"
label var none0			"SAME"
label var abch0			"OWN. & SECT."
label var f_school_a	"ENTRY"
label var t_retire2_a	"EXIT"
label var anti0			"OPPOSITE"

 
egen sum1 = rowtotal(ab0 ch0 abch0 none0 anti0 f_school_a t_retire2_a) 
egen sumer = total(sum1), by(c_code)		

** The loop creates figures for three subperiods. Only the first two are printed. 
forvalues i =1/3{
 graph hbar  (asis) ab0 ch0 abch0 none0 anti0 f_school_a t_retire2_a if period==`i', ///
	over(c_code, sort(sumer) descending  gap(*.5) label(labsize(vsmall))) stack  label legend(size(vsmall)) ///
	 ylabel(,labsize(vsmall)) legend(  row(2) region(lcolor(none))) scheme(s1mono) ///
	 name(bar_flows`i'f, replace) ylab(,nogrid) xsize(6) ///
		bar(1, fcolor(dknavy) lcolor(white) fintensity(100)) ///
		bar(2, fcolor(dknavy) lcolor(white) fintensity(60)) ///
		bar(3, fcolor(dknavy) lcolor(white) fintensity(40)) ///
		bar(4, fcolor(black) lcolor(white) fintensity(40)) ///
		bar(5, fcolor(black) lcolor(white) fintensity(10)) ///
		bar(6, fcolor(maroon) lcolor(white) fintensity(40)) ///
		bar(7, fcolor(maroon) lcolor(white) fintensity(90))		
		
graph export ..\graphs\bar_weighted_period_`i'.eps, replace			
		}
exit
