*-----------------------------------*
*	Weighted sample descriptors		*
*-----------------------------------*

** The file compares LITS and EUROSTAT data
** It produces Table B.5 
 
 
* Data from EUROSTAT to use as a comparison
*-----------------------------------------------
import delimited "..\data\general_stats.csv", clear 
replace value = "" if value==":"
replace value = subinstr(value," ","",.)
destring value, replace
drop flag

global name0 geo
qui do "..\do_files\country codes"
ren time year

egen id = group(age sex geo)
xtset id year
replace value = f.value if c_code=="POL" & year==1989

* Official statistics on GENDER
*---------------------------------

preserve
keep if sex!="Total"

drop if age=="Total" | age=="Unknown"| age=="Open-ended age class"

ren age age_old
gen aux = real(word(age_old,1))
replace aux =0.5 if aux==.

replace value = 0 if aux<20 & year==2005
collapse (sum) value , by(year c_code sex)

reshape wide value, i(year c_code) j(sex) string
gen female =  valueFemales/(valueMales+valueFemales)
keep female year c_code
label data "Percentage of females in transition countries. Source: Eurostat"
save female_pop, replace
restore


** Official statistics for AGE
*-------------------------------------
preserve
keep if sex =="Total"
drop if age=="Total" | age=="Unknown"| age=="Open-ended age class"

ren age age_old
gen aux = real(word(age_old,1))
replace aux =0.5 if aux==.

replace value = 0 if aux<20 & year==2005

egen totals = sum(value), by(c_code year)

gen age = aux*value/totals

collapse (sum) age , by(c_code year)
drop if age ==0  // No information on age in non-EU countries

label data "Average age per year in transition countries. Source: Eurostat"
save age_pop, replace
restore


** Obtain similar values from LiTS
*---------------------------------------------
use "..\data\data_user", clear

local vars 	"age fem deduc1 deduc3" 
collapse (mean) age_l= age fem_l=fem deduc1 deduc3 (first) c_code[aw=weight_0] , by(countryname year)

merge 1:1 c_code year using female_pop, gen(merge1)
merge 1:1 c_code year using age_pop, gen(merge2)

keep if year ==1989 | year ==2005
drop merge? 
 
reshape wide age_l age fem_l female deduc1 deduc3 , i(countryname) j(year)
order countryname age_l1989 age1989 age_l2005 age2005 fem_l1989 female1989 fem_l2005 ///
			female2005 deduc11989 deduc12005 deduc31989 deduc32005 c_code

foreach var of varlist _all{
capture replace `var' = round(`var',.01)
}

exit			
