/* Survival Data for individuals*/

 
use "..\data\data_user", clear

encode c_code, gen(cn)

* --> sample

egen some_indus = max(indus==2 | indus==3 | indus==4), by(id)


replace pubv = . if indus==5 | indus==1
 
* --> Dependent variable

egen retirees = max(t_retire2_a),by(id)
egen age_ret2 = max(age*(t_retire2_a==1& retirees==1) + age*(retirees==0) ), by(id)

gen failure = retirees==1

capture drop time_*
gen time_event = age_ret2 - 44
gen time_start = age - 45
gen time_end = age -44


* ---> INDEPENDENT VARIABLES

* Previous sector
egen age89_b = min(age), by(id)


replace industryv = . if workv ==.
replace sectorv = . if workv==.

gen old_sector = sectorv
replace old_sector = l.old_sector if old_sector==. 

gen old_ind = industryv
replace old_ind = l.old_ind if old_ind==. 

* Shares of employment
gen emp = unemp_a==0 & indus!=1 & indus!=5
egen tot_empl	= total(emp), by(country year)

egen empl_man_all = total(emp*(indus==2 )) , by( country year)
egen empl_serv_all = total(emp*(indus==4)) , by( country year)
egen empl_pub_all = total(emp*(pubv==1)) , by( country year)
egen empl_pri_all = total(emp*(pubv==0)) , by( country year)

egen empl_priv_all = total(emp*(pri==1)) , by( country year)
egen empl_den_all = total(emp*(den==1)) , by( country year)

local i =0
foreach var in pri pub{
egen empl_man_`var' = total(emp*(indus== 2 & pubv==`i')) , by( country year)
egen empl_serv_`var' = total(emp*(indus== 4 & pubv==`i')) , by( country year)
local ++i
}

gen share_man 	= empl_man_all/ tot_empl 
gen share_pub	= empl_pub_all/tot_empl 
gen share_pri	= empl_pri_all/tot_empl  
gen share_priv	= empl_priv_all/tot_empl  
gen share_den	= empl_den_all/tot_empl  


egen share_man_89 = max(share_man*(year==1989)), by(id)	
egen share_pri_89 = max((1-share_pub)*(year==1989)), by(id)	


*--> Risk measures

* Individual became at risk
egen init_indus = max(indus*(age==46)+ indus*(year==1989 & age89>46)),by(id)
egen init_pub 	= max((pubv==1&age==46)+ (pubv==1 & year==1989 & age89 > 46)),by(id)
egen init_pri 	= max((pubv==0& unemp_a==0 &age==46)+ (pubv==0 & unemp_a==0 & year==1989& age89>46)),by(id)

* Individual worked before retirement
gen aux = indus if f.t_retire2_a==1
egen last_indus = max(aux), by(id)
egen last_pub 	= max(pubv==1 & f.t_retire2_a ==1), by(id)
egen last_pri 	= max(pubv==0 & f.t_retire2_a ==1), by(id)
drop aux


local i =0
foreach var1 in pri pub {
local j = 0
	foreach var2 in man serv{
	local j = `j' +2
	local v _`var2'_`var1'
	
	foreach vs in sep tot_sep nosep risk risk2{
		capture drop `vs'`v'
	}
	
	gen sep`v' = (workv!=l.workv & l.workv!=. & l.indus==`j' & l.pubv==`i' ) 
	egen tot_sep`v' = total(sep`v'), by(country year)
	gen nosep`v' = tot_sep`v' ==0

	gen risk`v' = tot_sep`v'/ empl`v'
	replace risk`v' = 0 if empl`v'==0

}
local ++i
}

capture drop risk_sep_cur

egen risk_sep_cur = max(risk_man_pub*(indus== 2 & pub==1) + ///
					risk_man_pri*(indus== 2 & pri==1) +  ///
					risk_serv_pub*(indus==4 & pub==1) +  ///
					risk_serv_pri*(indus==4 & pri==1)), by(id year)
					
replace risk_sep_cur = l.risk_sep_cur if t_retire2_a==1					
					
				
* ENTRY
egen entry_indus = total(f_school_a), by(indus country year) 

egen entry_man_all = total(f_school_a*(industry==2)), by( country year) 
egen entry_serv_all = total(f_school_a*(industry==4)), by( country year) 

egen entry_pub_all = total(f_school_a*(pubv==1)), by( country year) 
egen entry_pri_all = total(f_school_a*(pubv==0)), by( country year) 
local i =0
foreach var1 in pri pub {
local j = 0
foreach var2 in man serv{
local j = `j' +2

foreach vs in aux entry new{
capture drop `vs'_`var2'_`var1'
}

gen aux_`var2'_`var1' = (f_school_a*(industry==`j' & pubv==`i')) 
egen entry_`var2'_`var1' = total(aux_`var2'_`var1'), by(country year) 
gen new_`var2'_`var1' 	= entry_`var2'_`var1'/ empl_`var2'_`var1' 
replace  new_`var2'_`var1' 	= 0 if  empl_`var2'_`var1' ==0
}
local ++i

}
	
egen entry_cur = max(new_man_pub*(indus== 2 & pub==1) + ///
					new_man_pri*(indus== 2 & pri==1) +  ///
					new_serv_pub*(indus==4 & pub==1) +  ///
					new_serv_pri*(indus==4 & pri==1)), by(id year)
					
replace entry_cur = l.entry_cur if t_retire2_a==1		

 
local i =0
foreach sect in pri pub {
egen aux_`sect' = total(f_school_a*(pubv==`i')) , by(country year)

sort id year
by id: gen cum_`sect' = sum(aux_`sect')
replace cum_`sect' = cum_`sect' / empl_`sect'_all
local ++i
}
*
local j = 0 
foreach sect in man serv{
local j = `j' +2
capture drop aux_`sect'
egen aux_`sect' = total(f_school_a*(industry==`j')) , by(country year)

sort id year
capture drop cum_`sect'
by id: gen cum_`sect' = sum(aux_`sect')
replace cum_`sect' = cum_`sect' / empl_`sect'_all
}
 
gen entry_ind2 = (cum_man*(indus== 2) + cum_serv*(indus==4 )) 
replace entry_ind2 = l.entry_ind2 if t_retire2_a ==1

gen entry_sect2 = (cum_pri*(pub== 0 & workv!=.) + cum_pub*(pub== 1 ))
replace entry_sect2 = l.entry_sect2 if t_retire2_a ==1
 

* Placebo Risk 
 foreach sect in pub pri{
foreach var in man serv{				

local v    _`var'_`sect' 
egen aux1`v'	= mean(risk`v')	 
egen aux2`v'	= mean(risk`v')	, by(year c_code)		

egen aux3`v'	= count(risk`v')	 
egen aux4`v'	= count(risk`v')	, by(year c_code)

capture drop risk4`v'
gen risk4`v' = aux1`v'*aux3`v'/(aux3`v'-aux4`v') - aux2`v'*aux4`v'/(aux3`v'-aux4`v') 	

capture drop aux1`v' aux2`v' aux3`v' aux4`v' 
}
}


 

replace indus= l.indus if t_retire2_a ==1
replace pub= l.pub if t_retire2_a ==1
replace pri= l.pri if t_retire2_a ==1

capture drop risk_plac_cur
egen risk_plac_cur =  total(risk4_man_pub*(indus== 2 & pub==1) + ///
					risk4_man_pri*(indus== 2 & pri==1) +  ///
					risk4_serv_pub*(indus==4 & pub==1) +  ///
					risk4_serv_pri*(indus==4 & pri==1)), by(id year)

 replace risk_plac_cur = l.risk_plac_cur if t_retire2_a==1
 
 xtset id year
gen man = indus==2
replace man = l.man if t_retire2_a==1	
replace pub = l.pub if t_retire2_a==1	
 
 
 * Technical variables
gen start = age==45 | (age89>45 & year ==1989)	
egen at_risk = max(age>45), by(id)		
egen empl = sum(emp), by(c_code year)
egen aux1 = sum(workv!= .), by(id)
gen lazy = aux1==0			
gen ages = age-45



preserve 	
drop if time_event<0
drop if age89>65
drop if some_indus==0
drop if lazy

  		

* Estimations

global xs 		"i.fem  ib1.educ i.mstat i.urban"
global firm  	"i.man i.pub"
global s_1989	"share_pri_89 share_man_89"
global s_exit 	"share_priv share_man share_den"
global entry	"entry_cur"
global entry2	"entry_ind2  entry_sect2"
 
stset ages , id(id) failure(t_retire2_a) origin(start)
global ifs   init_indus==2 | init_indus==4     
keep if $ifs
 
foreach var in $s_1989 $s_exit $entry $entry2 risk_sep_cur risk_plac_cur {
replace `var' = 100*`var'
}
 
 
 
** TABLE 1: COLUMNS NAMED W

streg $xs $firm i.cn  if $ifs     , d(ggamma) 
local L10 = `e(ll_0)'
local L1 = `e(ll)'
est store model0
capture local pvalue= -99
margins , dydx($xs $firm    ) post
*outreg2 using "surv_2017_mfx_ind",   dec(3) excel addstat(L10,`L10' , L1,`L1' , pvalue,`pvalue') replace
 
streg $xs $firm   risk_sep_cur $entry i.cn   if $ifs     , d(ggamma) 
local L10 = `e(ll_0)'
local L1 = `e(ll)'
est store model2
capture lrtest model0 model2 
capture local pvalue= `r(p)'
margins , dydx($xs $firm   risk_sep_cur $entry    ) post
*outreg2 using "surv_2017_mfx_ind",   dec(3) excel addstat(L10,`L10' , L1,`L1' , pvalue,`pvalue') 

streg $xs $firm   risk_sep_cur $entry $s_exit $s_1989  i.cn  if $ifs     , d(ggamma)  
local L10 = `e(ll_0)'
local L1 = `e(ll)'
est store model3
capture lrtest model0 model3 
capture local pvalue= `r(p)'
margins , dydx($xs $firm   risk_sep_cur $entry $s_exit $s_1989    ) post
*outreg2 using "surv_2017_mfx_ind",   dec(3) excel addstat(L10,`L10' , L1,`L1' , pvalue,`pvalue')
 
 

* TABLE D.2

* Young cohort
streg $xs $firm   risk_sep_cur $entry $s_exit $s_1989  i.cn  if $ifs  & age89<46     , d(ggamma)  
local L10 = `e(ll_0)'
local L1 = `e(ll)'
est store under3
capture lrtest under0 under3 
capture local pvalue= `r(p)'
margins , dydx($xs $firm   risk_sep_cur $entry $s_exit $s_1989    ) post
outreg2 using "surv_2017_ind_age",   dec(3) excel ctitle(under3) ///
	addstat(L10,`L10' , L1,`L1' , pvalue,`pvalue') 
	
 * Old cohort
streg $xs $firm   risk_sep_cur $entry $s_exit $s_1989  i.cn  if $ifs  & age89>45   , d(ggamma)  
local L10 = `e(ll_0)'
local L1 = `e(ll)'
est store over3
capture lrtest over0 over3 
capture local pvalue= `r(p)'
margins , dydx($xs $firm   risk_sep_cur $entry $s_exit $s_1989    ) post
outreg2 using "surv_2017_ind_age",   dec(3) excel ctitle(over3) ///
	addstat(L10,`L10' , L1,`L1' , pvalue,`pvalue') 
  
 *Placebo
 
 global ifs   init_indus==2 | init_indus==4   
  streg $xs $firm   risk_plac_cur $entry2 $s_exit $s_1989  i.cn  if $ifs    , d(ggamma) 
 margins , dydx($xs $firm   risk_plac_cur $entry2 $s_exit $s_1989   ) post

 
 
 *Figure D.2 - right panel
sts graph if e(sample), ci   xtitle("Analysis time " "(Initial date: age =45 years old)")	///
			scheme(s1mono)	legend(off) name(k_m1, replace) ytitle("Survival") ///
			title("Kaplan-Meier survival estimate")  ylab(0(.25)1 , angle(horizontal))


stcurve	 , 	survival    xtitle("Analysis time " "(Initial date: age =45 years old)") ///
			name(fitted1, replace) scheme(s1mono) title("Estimated survival function") ///
			ylab(0(.25)1 , angle(horizontal) grid)

graph combine k_m1 fitted1 , title("All individuals")	scheme(s1mono) ///
				name(combined, replace)  
				
				
* For figure 6
streg $xs $firm   i.cn  if $ifs     , d(ggamma)  
margins cn, post
 est store cns
est table cns

matrix l1 = r(coef)
 
